@@ -10,9 +10,10 @@
 #pragma once
 
 #include "kleo_export.h"
-#include <QObject>
 
-#include <libkleo/keyfilter.h>
+#include <Libkleo/KeyFilter>
+
+#include <QObject>
 
 #include <gpgme++/global.h>
 
@@ -22,6 +23,7 @@
 namespace GpgME
 {
 class Key;
+class UserID;
 }
 
 class QAbstractItemModel;
@@ -67,14 +69,16 @@ public:
 
     QFont font(const GpgME::Key &key, const QFont &baseFont) const;
     QColor bgColor(const GpgME::Key &key) const;
+    QColor bgColor(const GpgME::UserID &userID) const;
     QColor fgColor(const GpgME::Key &key) const;
+    QColor fgColor(const GpgME::UserID &userID) const;
     QIcon icon(const GpgME::Key &key) const;
 
     class Private;
+
 private:
     std::unique_ptr<Private> d;
     static KeyFilterManager *mSelf;
 };
 
 }
-
