@@ -21,6 +21,7 @@ class QString;
 namespace GpgME
 {
 class Key;
+class UserID;
 }
 
 namespace Kleo::DeVSCompliance
@@ -54,6 +55,14 @@ KLEO_EXPORT bool algorithmIsCompliant(std::string_view algo);
  */
 KLEO_EXPORT bool allSubkeysAreCompliant(const GpgME::Key &key);
 
+/**
+ * Returns true, if the key \p key is compliant with compliance mode "de-vs".
+ * This function behaves like DeVSCompliance::keyIsCompliant, but only considers
+ * user id \p id; all other user ids are ignored.
+ * \see keyIsCompliant
+ */
+KLEO_EXPORT bool userIDIsCompliant(const GpgME::UserID &id);
+
 /**
  * Returns true, if the key \p key is compliant with compliance mode "de-vs".
  * A key is considered compliant if all usable subkeys are compliant and if
